@@ -18,14 +18,18 @@
   # }
 
   .Call("spmd_initialize", PACKAGE = "pbdMPI")
-  .comm.size <- .Call("spmd_comm_size", 0L, PACKAGE = "pbdMPI")
-  .comm.rank <- .Call("spmd_comm_rank", 0L, PACKAGE = "pbdMPI")
-  assign(".comm.size", .comm.size, envir = .GlobalEnv)
-  assign(".comm.rank", .comm.rank, envir = .GlobalEnv)
+  # .comm.size <- .Call("spmd_comm_size", 0L, PACKAGE = "pbdMPI")
+  # .comm.rank <- .Call("spmd_comm_rank", 0L, PACKAGE = "pbdMPI")
+  # assign(".comm.size", .comm.size, envir = .GlobalEnv)
+  # assign(".comm.rank", .comm.rank, envir = .GlobalEnv)
+
+  invisible()
 } # End of .onLoad().
 
 .onUnload <- function(libpath){
   pbdMPI:::spmd.finalize(mpi.finalize = FALSE)
   library.dynam.unload("pbdMPI", libpath)
+
+  invisible()
 } # End of .onUnload().
 
